==> SMCSolver_1.3-2006.12.06-20.tgz: SMCSolver_1.3/test-lib.f90 <==
program test_lib
use fi_int
use smc_int
use smc_tools
use ponte_f_f, only:wout, debug, verb
implicit none
real(kind(0.d0)),dimension(:,:,:),allocatable:: a
real(kind(0.d0)),dimension(:,:),allocatable:: g,x0
integer :: i,j,m,itermax,method
logical :: ds
real(kind(0.d0)):: drift, norm1,myeps, s

debug=.false.
!debug=.true.
verb=.true.
!verb=.false.

write(*,*)
write(*,*) "This is a sample program that calls some subroutines of the library libsmcsolver.a"
write(*,*)
write(*,*) "Reading data file from Examples/usedA"
open(file='Examples/usedA',unit=2)
read(2,*)m
read(2,*)m,m
allocate(a(m,m,3),g(m,m),x0(m,m))
A(:,:,1)=0.d0
A(:,:,2)=0.d0
A(:,:,3)=0.d0
 read(2,*) A(:,:,1)
read(2,*)m,m
 read(2,*) A(:,:,2)
read(2,*)m,m
 read(2,*) A(:,:,3)

write(*,*) "done...beginning computations: we shall call subroutine fi"
write(*,*)
!do j=1,m
!   do i=1,m
!         read(2,*) A(:,:,1)
!   end do
!end do
!do j=1,m
!   do i=1,m
!         read(2,*) A(i,j,2)
 !  end do
!end do
!do j=1,m
!   do i=1,m
!         read(2,*) A(i,j,3)
!   end do
!end do


! normalization
!G=A(:,:,1)+A(:,:,2)+A(:,:,3)
!do i=1,m
!s=sum(G(i,:))

!A(i,:,1)=A(i,:,1)/s
!A(i,:,2)=A(i,:,2)/s
!A(i,:,3)=A(i,:,3)/s
!end do

x0=0.d0
ds=.false.
method = 1
myeps=1.e-12
itermax = 200


call fi(A=A, doshift=ds, method=method, eps=myeps, maxit=itermax, x0=X0, G=G, &
drift=drift, err=norm1)

write(*,*)"drift=",drift,"error=",norm1

write(*,*) "now we print the matrix G"
do i=1,m
  do j=1,m
  write(*,*) "G(",i,j,")=",G(i,j)
  end do
end do

end program test_lib

==> SMCSolver_2.2-2024.02.29.tgz: SMCSolver_2.2/test-lib.f90 <==
program test_lib
use fi_int
use smc_int
use smc_tools
implicit none
real(kind(0.d0)),dimension(:,:,:),allocatable:: a
real(kind(0.d0)),dimension(:,:),allocatable:: g,x0
integer :: i,j,m,itermax,method
real(kind(0.d0)):: drift, norm1,myeps
integer algflag   ! input:   0=basic,  1=shift acceleration,  2=tau shift 3=duoble shift  4=diagonal adjustment
debug=.false.
!debug=.true.
verb=.true.
!verb=.false.

write(*,*)
write(*,*) "This is a sample program that calls some subroutines of the library libsmcsolver.a"
write(*,*)
write(*,*) "Reading data file from Examples/usedA"
open(file='Examples/usedA',unit=2)
read(2,*)m
read(2,*)m,m
allocate(a(m,m,3),g(m,m),x0(m,m))
A(:,:,1)=0.d0
A(:,:,2)=0.d0
A(:,:,3)=0.d0
 read(2,*) A(:,:,1)
read(2,*)m,m
 read(2,*) A(:,:,2)
read(2,*)m,m
 read(2,*) A(:,:,3)

write(*,*) "done...beginning computations: we shall call subroutine fi"
write(*,*)
!do j=1,m
!   do i=1,m
!         read(2,*) A(:,:,1)
!   end do
!end do
!do j=1,m
!   do i=1,m
!         read(2,*) A(i,j,2)
 !  end do
!end do
!do j=1,m
!   do i=1,m
!         read(2,*) A(i,j,3)
!   end do
!end do


! normalization
!G=A(:,:,1)+A(:,:,2)+A(:,:,3)
!do i=1,m
!s=sum(G(i,:))

!A(i,:,1)=A(i,:,1)/s
!A(i,:,2)=A(i,:,2)/s
!A(i,:,3)=A(i,:,3)/s
!end do

x0=0.d0
algflag=0
method = 1
myeps=1.e-12
itermax = 200

call fi(A=A, ds=algflag, method=method, eps=myeps, maxit=itermax, x0=X0, G=G, &
drift=drift, err=norm1)

write(*,*)"drift=",drift,"error=",norm1

write(*,*) "now we print the matrix G"
do i=1,m
  do j=1,m
  write(*,*) "G(",i,j,")=",G(i,j)
  end do
end do

end program test_lib
